@@ -1137,7 +1137,7 @@ class OWsrcalc_idpower(XoppyWidget, WidgetDecorator):
             f.close()
 
             if platform.system() == "Windows":
-                command = os.path.join(locations.home_bin(),'srcalc')
+                command = "\"" + os.path.join(locations.home_bin(), 'srcalc') + "\""
             else:
                 command = "'" + os.path.join(locations.home_bin(), 'srcalc') + "'"
             print("Running command '%s' in directory: %s "%(command, locations.home_bin_run()))
